@@ -30,7 +30,7 @@ debugger protocol.
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Test::Differences;
 use IO::Socket;
@@ -42,6 +42,7 @@ require Exporter; *import = \&Exporter::import;
 
 our @EXPORT = qw(
     dbgp_response_cmp
+    dbgp_parsed_response_cmp
     dbgp_init_is
     dbgp_command_is
 
@@ -68,6 +69,15 @@ sub dbgp_response_cmp {
     eq_or_diff($cmp, $expected);
 }
 
+sub dbgp_parsed_response_cmp {
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
+    my ($res, $expected) = @_;
+    my $cmp = _extract_command_data($res, $expected);
+
+    eq_or_diff($cmp, $expected);
+}
+
 sub _extract_command_data {
     my ($res, $expected) = @_;
 
@@ -222,7 +232,7 @@ Mattia Barbon <mbarbon@cpan.org>
 
 =head1 LICENSE
 
-Copyright (c) 2015 Mattia Barbon. All rights reserved.
+Copyright (c) 2015-2016 Mattia Barbon. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
